Class: Yahoo::Answers::Result
- Inherits:
-
Object
- Object
- Yahoo::Answers::Result
- Defined in:
- lib/yahoo/answers.rb
Overview
A Result contains the following fields
idunique id of the question
typestate of the question (answered, open, ...)
subjectquestion subject
contentquestion text
datepre-formatted date of when the question was submitted
timestampunix timestamp of when the question was submitted
linklink to the question
categorycategory that the question is listed under
category_idunique id of the category
user_idunique id of the user who posted the question
user_nicknickname of the user who posted the question
user_photo_urlURL of the user's photo
num_answersnumber of answers to the question
num_commentsnumber of comments to the question
answerthe text of the chosen answer
answer_timestampunix time of when the answer was submitted
answer_award_timestampunix time of when the answer was given an award
answerer_idunique id of the user who submitted the answer
answerer_nicknickname of the user who submitted the answer